/*-
 * Copyright (c) 2018-2023 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.fedoraproject.xmvn.connector.maven;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Singleton;

import org.apache.maven.lifecycle.MojoExecutionConfigurator;
import org.apache.maven.lifecycle.internal.DefaultMojoExecutionConfigurator;
import org.apache.maven.plugin.MojoExecution;
import org.apache.maven.plugin.descriptor.PluginDescriptor;
import org.apache.maven.project.MavenProject;
import org.eclipse.sisu.Priority;

/**
 * @author Mikolaj Izdebski
 */
@Named
@Singleton
@Priority( 100 )
public class XMvnMojoExecutionConfigurator
    implements MojoExecutionConfigurator
{
    @Inject
    private DefaultMojoExecutionConfigurator delegate;

    @Override
    public void configure( MavenProject project, MojoExecution execution, boolean allowPluginLevelConfig )
    {
        PluginDescriptor originalPluginDescriptor = execution.getMojoDescriptor().getPluginDescriptor();

        PluginDescriptor aliasedPluginDescriptor = originalPluginDescriptor.clone();
        aliasedPluginDescriptor.setGroupId( execution.getPlugin().getGroupId() );
        aliasedPluginDescriptor.setArtifactId( execution.getPlugin().getArtifactId() );

        try
        {
            execution.getMojoDescriptor().setPluginDescriptor( aliasedPluginDescriptor );
            delegate.configure( project, execution, allowPluginLevelConfig );
        }
        finally
        {
            execution.getMojoDescriptor().setPluginDescriptor( originalPluginDescriptor );
        }
    }
}
